@@ -1,6 +1,8 @@
+import re
+
 from itertools import chain
 from ast import literal_eval
-import re
+from datetime import datetime
 
 from CGPCLI.Errors import NotValidCGPStringError
 
@@ -16,39 +18,33 @@ def parse_to_python_object(string):
                     yield (arg1,) + others, src
         return result
     
-    number_regex = re.compile(r"(\#(?:0|[1-9]\d*)(?:\.\d+)?)\s*(.*)", re.DOTALL) #(r"(\#(?:-?0?\S*)(?:\.\d+)?)\s*(.*)
-    
-    def parse_number(src):
-        match = number_regex.match(src)
-        if match is not None:
-            number, src = match.groups()
-            yield int(number[1:]), src
-    
     date_regex = re.compile(r"(\#T(?:\d{2}-\d{2}-\d{4}_\d{2}:\d{2}:\d{2}))\s*(.*)", re.DOTALL)
     
     def parse_date(src):
         match = date_regex.match(src)
         if match is not None:
             date, src = match.groups()
-            yield date[2:12] + ' ' + date[13:], src
-                    
-    ip_regex = re.compile(r"(\#I(?:\S*)(?:\.\d+)?)\s*(.*)", re.DOTALL)
-        
-    def parse_ip(src):
-        match = ip_regex.match(src)
+            yield datetime.strptime(date, '#T%d-%m-%Y_%H:%M:%S'), src
+            
+    cert_regex = re.compile(r"(\[.*\])(.*)", re.DOTALL)        
+    
+    def parse_cert(src):
+        match = cert_regex.match(src)
         if match is not None:
-            ip, src = match.groups()
-            yield literal_eval(ip[1:]), src
+            sert, src = match.groups()
+            yield sert, src    
                         
-    string_regex = re.compile(r"(\"(?:(?:\"[\w\s]*\")?(?:[^\"]*))\")\s*(.*)", re.DOTALL)
-    #(\"(?:[^\\']|\\['\\bfnrt]|\\u[0-9a-fA-F]{4})*?)\"\s*(.*) not full
+    string_regex = re.compile(r"(?:(?:\"([(\\\")\w\s\\\.\[\]\*/~:()#@!&<>-]*)\")|([\w\.@-]*))(.*)",
+                              re.DOTALL)
+    
     def parse_string(src):
         match = string_regex.match(src)
         if match is not None:
-            string, src = match.groups()
-            if string.count('"') == 4:
-                string = f'\'{string[1:-1]}\''
-            yield literal_eval(string), src
+            a,b,c = match.groups()
+            string = match.groups()[1] or match.groups()[0]
+            src = match.groups()[2].strip()
+                
+            yield string, src
     
     def parse_word(word, value=None):
         l = len(word)
@@ -64,22 +60,21 @@ def parse_to_python_object(string):
     
     def parse_value(src):
         for match in chain(
-            parse_string(src),
-            parse_ip(src),
-            parse_number(src),
             parse_date(src),
+            parse_cert(src),
             parse_array(src),
             parse_object(src),
             parse_true(src),
             parse_false(src),
             parse_null(src),
+            parse_string(src),
             ):
             yield match
             return
     
-    parse_left_square_bracket = parse_word("(")
-    parse_right_square_bracket = parse_word(")")
-    parse_empty_array = sequence(parse_left_square_bracket, parse_right_square_bracket)
+    parse_left_bracket = parse_word("(")
+    parse_right_bracket = parse_word(")")
+    parse_empty_array = sequence(parse_left_bracket, parse_right_bracket)
     
     def parse_array(src):
         for _, src in parse_empty_array(src):
@@ -87,9 +82,9 @@ def parse_to_python_object(string):
             return
     
         for (_, items, _), src in sequence(
-            parse_left_square_bracket,
+            parse_left_bracket,
             parse_comma_separated_values,
-            parse_right_square_bracket,
+            parse_right_bracket,
             )(src):
             yield items, src
     
@@ -123,12 +118,12 @@ def parse_to_python_object(string):
             )(src):
             yield items, src
     
-    parse_colon = parse_word("=")
+    parse_equals = parse_word("=")
     
     def parse_keyvalue(src):
         for (key, _, value, _), src in sequence(
             parse_string,
-            parse_colon,
+            parse_equals,
             parse_value,
             parse_semicolomn,
             )(src):
@@ -146,70 +141,7 @@ def parse_to_python_object(string):
         for keyvalue, src in parse_keyvalue(src):
             yield keyvalue, src
     
-    def preparse(s):
-        s = s.split('\n')
-        string_regex = re.compile(r"([\w*0-9-\/\.!\[\]\#:@]+)([^-\w\"#]*)(.*)", re.DOTALL)
-    
-        for i in range(len(s)):
-            s[i] = s[i].strip().replace('\e', '\\n')
-            
-            #try to find "x = ..." seq
-            match = string_regex.match(s[i])
-            if match is not None:
-                
-                s[i] = '"' + match.groups()[0] + '"' + match.groups()[1]
-    
-                match_next = string_regex.match(match.groups()[2])
-
-                if match_next is not None:
-    
-                    if match_next.groups()[2] == '':
-                        #numbers
-                        #check numbers
-                        s[i] += '"' + match_next.groups()[0] + '"' + match_next.groups()[1]
-                       
-                        continue
-                    
-                    s[i] += ''.join(preparse(''.join(match_next.groups())))
-                
-                #"" && "-1"
-                else:
-                    s[i] += match.groups()[2]
-               
-    
-            else:
-                #try to find "..." values
-                half_string_regex = re.compile(r'\"([\w*0-9-\/ \.!|\#\[\];]+)\"(.*)', re.DOTALL)
-                
-                match = half_string_regex.match(s[i])
-                if match is not None:
-                    s[i] = '"' + match.groups()[0] + '"'
-                    
-                    string_parts_regex = re.compile(r'([^-\w\"]*)([\w*0-9-\/\.!|\#]+)([^-\w\"]*)(.*)', re.DOTALL)
-                    match_next = string_parts_regex.match(match.groups()[1])
-                    
-                    if match_next is not None:
-                        
-                        s[i] += match_next.groups()[0] + '"' + match_next.groups()[1] + '"' + match_next.groups()[2]
-                    
-                        s[i] += ''.join(preparse(match_next.groups()[3]))
-                    
-                    else:
-                        s[i] += match.groups()[1]
-                     
-                #try to parse objects   
-                else:
-                    last_chance = re.compile(r'(.)\"?([\w*0-9-\/ \.!|\#\[\];]+)\"?([^\w])(.*)', re.DOTALL)
-                    match = last_chance.match(s[i])
-                    
-                    if match is not None:                        
-                        s[i] = match.groups()[0] + '"' + match.groups()[1] + '"' + match.groups()[2]
-                    
-                        s[i] += ''.join(preparse(match.groups()[3]))
-                         
-        return ''.join(s)
-    
-    string = preparse(string)
+    string = string.replace('\n', '')
     
     match = list(parse_value(string))
    
@@ -218,7 +150,7 @@ def parse_to_python_object(string):
     
     result, src = match[0]
     
-    if src.strip():
+    if result is None:
         raise NotValidCGPStringError()
     return result    
 
